@@ -117,7 +117,8 @@ def main(hall_width_L, hall_height_h_o, hall_height_h_m, number_frames, frame_sp
 
 # -------------------------------------------------------------
     # Member Hinges
-    MemberHinge(1, "Local", inf, inf, inf,  inf, 0, inf, "Rotational Release My")
+    MemberHinge(1, "Local", rotational_release_mz=inf)
+
 
 # -------------------------------------------------------------
     # Members
@@ -199,12 +200,6 @@ def main(hall_width_L, hall_height_h_o, hall_height_h_m, number_frames, frame_sp
     # Solids
     Solid(1, "2 3 4 5 6 7", 2)
 
-# -------------------------------------------------------------
-    # Sets
-    LineSet()
-    MemberSet()
-    SurfaceSet()
-
 # -------------------------------------------------------------
     print('Load Cases/Loads...')
 
