@@ -1,4 +1,4 @@
-from RFEM.initModel import clearAtributes, Model, ConvertStrToListOfInt
+from RFEM.initModel import clearAttributes, Model, ConvertStrToListOfInt
 from RFEM.enums import ObjectTypes
 
 
@@ -23,7 +23,7 @@ class Material():
         clientObject = model.clientModel.factory.create('ns0:material')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Material No.
         clientObject.no = no
