@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, ConvertToDlString, clearAtributes
+from RFEM.initModel import Model, ConvertToDlString, clearAttributes
 from RFEM.enums import *
 
 class LineLoad():
@@ -29,7 +29,7 @@ class LineLoad():
         clientObject = model.clientModel.factory.create('ns0:line_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Line Load No.
         clientObject.no = no
@@ -118,7 +118,7 @@ class LineLoad():
         clientObject = model.clientModel.factory.create('ns0:line_load')
 
         # Clears object attributes | Sets all attributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Line Load No.
         clientObject.no = no
@@ -370,7 +370,7 @@ class LineLoad():
         clientObject = model.clientModel.factory.create('ns0:line_load')
 
         # Clears object attributes | Sets all attributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Line Load No.
         clientObject.no = no
@@ -601,7 +601,7 @@ class LineLoad():
         clientObject = model.clientModel.factory.create('ns0:line_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Line Load No.
         clientObject.no = no
