@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAtributes, ConvertToDlString
+from RFEM.initModel import Model, clearAttributes, ConvertToDlString
 from RFEM.enums import LoadDirectionType, NodalLoadType, NodalLoadSpecificDirectionType
 
 class NodalLoad():
@@ -27,7 +27,7 @@ class NodalLoad():
         clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Nodal Force No.
         clientObject.no = no
@@ -104,7 +104,7 @@ class NodalLoad():
         clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Nodal Force No.
         clientObject.no = no
@@ -245,7 +245,7 @@ class NodalLoad():
         clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Nodal Force No.
         clientObject.no = no
@@ -367,7 +367,7 @@ class NodalLoad():
         clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Nodal Force No.
         clientObject.no = no
@@ -495,7 +495,7 @@ class NodalLoad():
         clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Nodal Force No.
         clientObject.no = no
