@@ -1,6 +1,6 @@
 from pytest import param
 from RFEM.enums import MemberNonlinearityType
-from RFEM.initModel import ConvertToDlString, Model, clearAtributes
+from RFEM.initModel import ConvertToDlString, Model, clearAttributes
 
 class MemberNonlinearity():
     def __init__(self,
@@ -26,7 +26,7 @@ class MemberNonlinearity():
         clientObject = model.clientModel.factory.create('ns0:member_nonlinearity')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Member Nonlinearity No.
         clientObject.no = no
